@@ -11,6 +11,7 @@ import pstats
 import os
 import logging as log
 import pprint
+import re
 from typing import (
     Any, Dict, Optional, Union, Tuple, Callable, Iterable, List, Set,
     cast, Sequence)
@@ -20,15 +21,17 @@ import time as clock
 import uuid
 
 import networkx as nx
+import pytest
 
 from vivarium.core.store import (
     hierarchy_depth, Store, generate_state, view_values)
-from vivarium.core.emitter import get_emitter
+from vivarium.core.emitter import get_emitter, Emitter
 from vivarium.core.process import (
     Process,
     ParallelProcess,
     Step,
 )
+from vivarium.core.composer import Composite
 from vivarium.core.serialize import serialize_value
 from vivarium.library.topology import (
     get_in,
@@ -39,9 +42,9 @@ from vivarium.library.topology import (
 )
 from vivarium.core.types import (
     HierarchyPath, Topology, State, Update, Processes, Steps,
-    Flow)
+    Flow, Schema)
 
-pretty = pprint.PrettyPrinter(indent=2, sort_dicts=False)
+pretty = pprint.PrettyPrinter(indent=2)
 
 
 def pp(x: Any) -> None:
@@ -355,6 +358,7 @@ class _StepGraph:
 class Engine:
     def __init__(
             self,
+            composite: Optional[Composite] = None,
             processes: Optional[Processes] = None,
             steps: Optional[Steps] = None,
             flow: Optional[Flow] = None,
@@ -378,6 +382,10 @@ class Engine:
         """Defines simulations
 
         Args:
+            composite: A :term:`Composite`, which specifies the processes,
+                steps, flow, and topology. This is an alternative to passing
+                in processes and topology dict, which can not be loaded
+                at the same time.
             processes: A dictionary that maps :term:`process` names to
                 process objects. You will usually get this from the
                 ``processes`` key of the dictionary from
@@ -430,31 +438,8 @@ class Engine:
         self.initial_state = initial_state or {}
         self.emit_step = emit_step
 
-        # get the processes, topology, and store
-        if processes and topology and not store:
-            self.processes = processes
-            self.steps = steps or {}
-            self.flow = flow or {}
-            self.topology = topology
-            # initialize the store
-            self.state: Store = generate_state(
-                self.processes,
-                self.topology,
-                self.initial_state,
-                self.steps,
-                self.flow,
-            )
-
-        elif store:
-            self.state = store
-            # get processes and topology from the store
-            self.processes = self.state.get_processes()
-            self.steps = self.state.get_steps() or {}
-            self.flow = self.state.get_flow() or {}
-            self.topology = self.state.get_topology()
-        else:
-            raise Exception(
-                'load either store or (processes and topology) into Engine')
+        # make the processes, topology, steps, flow, and store
+        self._make_store(store, composite, processes, steps, flow, topology)
 
         # display settings
         self.experiment_name = experiment_name or self.experiment_id
@@ -464,7 +449,7 @@ class Engine:
         self.progress_bar = progress_bar
         self.time_created = timestamp()
         if self.display_info:
-            self.print_display()
+            self._print_display()
 
         # parallel settings
         self.invoke = invoke or InvokeProcess
@@ -476,6 +461,7 @@ class Engine:
         self._step_paths: Dict[HierarchyPath, Process] = {}
         self._find_process_paths(self.processes, self.flow)
         self._find_step_paths(self.steps, self.flow)
+        self._validate_steps_and_flow(self._step_paths, self.flow)
 
         # emitter settings
         emitter_config = emitter
@@ -484,7 +470,7 @@ class Engine:
         else:
             emitter_config = dict(emitter_config)
         emitter_config['experiment_id'] = self.experiment_id
-        self.emitter = get_emitter(emitter_config)
+        self.emitter: Emitter = get_emitter(emitter_config)
 
         self.emit_topology = emit_topology
         self.emit_processes = emit_processes
@@ -500,11 +486,11 @@ class Engine:
             for path in self.process_paths}
 
         # run the steps
-        self._run_steps()
+        self.run_steps()
 
         # run the emitter
-        self.emit_configuration()
-        self.emit_data()
+        self._emit_configuration()
+        self._emit_store_data()
 
         # logging information
         log.info('experiment %s', str(self.experiment_id))
@@ -515,6 +501,74 @@ class Engine:
         log.info('\nTOPOLOGY:')
         log.info(pf(self.topology))
 
+    @staticmethod
+    def _validate_steps_and_flow(
+            step_paths: Dict[HierarchyPath, Process],
+            flow: Flow,
+            path: HierarchyPath = tuple()) -> None:
+        '''Check that every Step in flow is in steps.'''
+        for key, sub_flow in flow.items():
+            if isinstance(sub_flow, dict):
+                Engine._validate_steps_and_flow(
+                    step_paths, sub_flow, path + (key,))
+            else:
+                assert isinstance(sub_flow, list)
+                for dependency in sub_flow:
+                    if dependency not in step_paths:
+                        raise Exception(
+                            f'Unknown dependency step {dependency} is '
+                            'in the flow')
+
+    def _make_store(
+            self,
+            store: Store = None,
+            composite: Composite = None,
+            processes: Processes = None,
+            steps: Steps = None,
+            flow: Flow = None,
+            topology: Topology = None,
+    ) -> None:
+        """
+        If a :term:`Store` is provided, retrieve the :term:`Processes`,
+        :term:`Steps`, :term:`Flow`, and :term:`Topology`. If a
+        :term:`Composite` or its attributes are provided, create a
+        store. These are interchangeable.
+        """
+        if not store:
+            if processes and topology:
+                self.processes = processes
+                self.steps = steps or {}
+                self.flow = flow or {}
+                self.topology = topology
+            elif composite:
+                self.processes = composite.processes
+                self.steps = composite.steps
+                self.flow = composite.flow
+                self.topology = composite.topology
+            else:
+                raise Exception(
+                    'load either composite, store, or '
+                    '(processes and topology) into Engine')
+
+            # initialize the store
+            self.state: Store = generate_state(
+                self.processes,
+                self.topology,
+                self.initial_state,
+                self.steps,
+                self.flow,
+            )
+
+        else:
+            self.state = store
+            # build the processes' views
+            self.state.build_topology_views()
+            # get processes and topology from the store
+            self.processes = self.state.get_processes()
+            self.steps = self.state.get_steps() or {}
+            self.flow = self.state.get_flow() or {}
+            self.topology = self.state.get_topology()
+
     def _add_step_path(
             self,
             step: Step,
@@ -569,7 +623,7 @@ class Engine:
         for path, step in tree.items():
             self._add_step_path(step, path, get_in(flow, path))
 
-    def emit_configuration(self) -> None:
+    def _emit_configuration(self) -> None:
         """Emit experiment configuration."""
         data: Dict[str, Any] = {
             'time_created': self.time_created,
@@ -589,7 +643,7 @@ class Engine:
             'data': data}
         self.emitter.emit(emit_config)
 
-    def emit_data(self) -> None:
+    def _emit_store_data(self) -> None:
         """Emit the current simulation state.
         Only variables with ``_emit=True`` are emitted.
         """
@@ -601,7 +655,7 @@ class Engine:
             'data': serialize_value(data)}
         self.emitter.emit(emit_config)
 
-    def invoke_process(
+    def _invoke_process(
             self,
             process: Process,
             path: HierarchyPath,
@@ -649,9 +703,9 @@ class Engine:
     ) -> Tuple[Defer, Store]:
         """Start generating a process's update.
 
-        This function is similar to :py:meth:`invoke_process` except in
+        This function is similar to :py:meth:`_invoke_process` except in
         addition to triggering the computation of the process's update
-        (by calling ``invoke_process``), it also generates a
+        (by calling ``_invoke_process``), it also generates a
         :py:class:`Defer` object to transform the update into absolute
         terms.
 
@@ -668,7 +722,7 @@ class Engine:
             ``store``.
         """
 
-        update = self.invoke_process(
+        update = self._invoke_process(
             process,
             path,
             interval,
@@ -681,7 +735,7 @@ class Engine:
 
         return absolute, store
 
-    def process_state(
+    def _process_state(
             self,
             path: HierarchyPath,
     ) -> Tuple[Store, State]:
@@ -709,7 +763,7 @@ class Engine:
 
         return store, states
 
-    def calculate_update(
+    def _calculate_update(
             self,
             path: HierarchyPath,
             process: Process,
@@ -726,7 +780,7 @@ class Engine:
             Tuple of the deferred update (relative to the root of
             ``path``) and the store at ``path``.
         """
-        store, states = self.process_state(path)
+        store, states = self._process_state(path)
         if process.update_condition(interval, states):
             return self._process_update(
                 path, process, store, states, interval)
@@ -776,11 +830,11 @@ class Engine:
 
         if deletions:
             for deletion in deletions:
-                self.delete_path(deletion)
+                self._delete_path(deletion)
 
         return view_expire
 
-    def delete_path(
+    def _delete_path(
             self,
             deletion: HierarchyPath
     ) -> None:
@@ -807,7 +861,7 @@ class Engine:
                         raise e
                 del self._step_paths[path]
 
-    def _run_steps(self) -> None:
+    def run_steps(self) -> None:
         """Run all the steps in the simulation."""
         layers = self._step_graph.get_execution_layers()
         for layer in layers:
@@ -822,7 +876,7 @@ class Engine:
                 #  generate_paths() add a schema attribute to the Deriver.
                 #  PyCharm's type check reports:
                 #    Type Process doesn't have expected attribute 'schema'
-                update, store = self.calculate_update(
+                update, store = self._calculate_update(
                     path, step, 0)
                 deferred_updates.append((update, store))
 
@@ -834,7 +888,7 @@ class Engine:
             if view_expire:
                 self.state.build_topology_views()
 
-    def send_updates(
+    def _send_updates(
             self,
             update_tuples: list
     ) -> None:
@@ -854,7 +908,7 @@ class Engine:
         if view_expire:
             self.state.build_topology_views()
 
-        self._run_steps()
+        self.run_steps()
 
     def update(
             self,
@@ -866,17 +920,17 @@ class Engine:
         """
         clock_start = clock.time()
         self.run_for(interval=interval, force_complete=True)
-        self.check_complete()
+        self._check_complete()
         runtime = clock.time() - clock_start
         if self.display_info:
-            self.print_summary(runtime)
+            self._print_summary(runtime)
 
     def complete(self) -> None:
         """Force all processes to complete at the current global time"""
         self.run_for(interval=0, force_complete=True)
-        self.check_complete()
+        self._check_complete()
 
-    def check_complete(self) -> None:
+    def _check_complete(self) -> None:
         """Check that all processes completed"""
         for path, advance in self.front.items():
             assert advance['time'] == self.global_time, \
@@ -932,7 +986,7 @@ class Engine:
                 if process_time <= self.global_time:
 
                     # get the time step
-                    store, states = self.process_state(path)
+                    store, states = self._process_state(path)
                     process_timestep = process.calculate_timestep(states)
 
                     if force_complete:
@@ -995,16 +1049,16 @@ class Engine:
                         advance['update'] = {}
                         paths.append(path)
 
-                self.send_updates(updates)
+                self._send_updates(updates)
 
                 # display and emit
                 if self.progress_bar:
                     print_progress_bar(self.global_time, end_time)
                 if self.emit_step == 1:
-                    self.emit_data()
+                    self._emit_store_data()
                 elif emit_time <= self.global_time:
                     while emit_time <= self.global_time:
-                        self.emit_data()
+                        self._emit_store_data()
                         emit_time += self.emit_step
 
             else:
@@ -1033,7 +1087,7 @@ class Engine:
                 total_stats.add(stats)
             self.stats = total_stats
 
-    def print_display(self) -> None:
+    def _print_display(self) -> None:
         """Print simulation metadata."""
         date, time = self.time_created.split('.')
         print('\nSimulation ID: {}'.format(self.experiment_id))
@@ -1045,7 +1099,7 @@ class Engine:
         if self.description:
             print('Description: {}'.format(self.description))
 
-    def print_summary(
+    def _print_summary(
             self,
             runtime: float
     ) -> None:
@@ -1079,3 +1133,77 @@ def print_progress_bar(
     # Print New Line on Complete
     if iteration == total:
         print()
+
+
+def test_flow_with_extra_step() -> None:
+    class StepA(Step):
+
+        def ports_schema(self) -> Schema:
+            return {
+                'a': {'_default': 1}
+            }
+
+        def next_update(self, timestep: float, states: State) -> Update:
+            return {}
+
+    class ProcessB(Process):
+
+        def ports_schema(self) -> Schema:
+            return {
+                'b': {'_default': 1}
+            }
+
+        def next_update(self, timestep: float, states: State) -> Update:
+            return {}
+
+
+    expected_error = re.escape(
+        'Unknown dependency step (\'stepA2\',) is in the flow')
+    with pytest.raises(Exception, match=expected_error):
+        _ = Engine(
+            processes={'procB': ProcessB()},
+            steps={'stepA1': StepA()},
+            topology={
+                'stepA1': {'a': ('a',)},
+                'procB': {'b': ('b',)},
+            },
+            flow={'stepA1': [('stepA2',)]},
+        )
+
+def test_flow_with_valid_steps() -> None:
+    class StepA(Step):
+
+        def ports_schema(self) -> Schema:
+            return {
+                'a': {'_default': 1}
+            }
+
+        def next_update(self, timestep: float, states: State) -> Update:
+            return {}
+
+    class ProcessB(Process):
+
+        def ports_schema(self) -> Schema:
+            return {
+                'b': {'_default': 1}
+            }
+
+        def next_update(self, timestep: float, states: State) -> Update:
+            return {}
+
+    _ = Engine(
+        processes={'procB': ProcessB()},
+        steps={
+            'stepA1': StepA(),
+            'stepA2': StepA(),
+        },
+        topology={
+            'stepA1': {'a': ('a',)},
+            'stepA2': {'a': ('a',)},
+            'procB': {'b': ('b',)},
+        },
+        flow={
+            'stepA1': [('stepA2',)],
+            'stepA2': [],
+        },
+    )
