@@ -11,6 +11,7 @@ from multiprocessing import Pipe
 from multiprocessing import Process as Multiprocess
 from multiprocessing.connection import Connection
 import pstats
+import pickle
 from typing import (
     Any, Dict, Optional, Union, List)
 from warnings import warn
@@ -90,12 +91,41 @@ class Process(metaclass=abc.ABCMeta):
         class can provide a ``defaults`` class variable to specify the
         process defaults as a dictionary.
 
+        Note that subclasses should call the superclass init function
+        first. This allows the superclass to correctly save the initial
+        parameters before they are mutated by subclass constructor code.
+        We need access to the original parameters for serialization to
+        work properly.
+
         Args:
-            parameters: Override the class defaults. If this contains a
-                ``_register`` key, the process will register itself in
-                the process registry.
+            parameters: Override the class defaults. This dictionary may
+                also contain the following special keys:
+
+                * ``name``: Saved to ``self.name``.
+                * ``_original_parameters``: Returned by
+                  ``__getstate__()`` for serialization.
+                * ``_schema``: Overrides the schema.
+                * ``_parallel``: Indicates that the process should be
+                  parallelized. ``self.parallel`` will be set to True.
+                * ``_condition``: Path to a variable whose value will be
+                  returned by
+                  :py:meth:`vivarium.core.process.Process.update_condition`.
+                * ``time_step``: Returned by
+                  :py:meth:`vivarium.core.process.Process.calculate_timestep`.
         """
         parameters = parameters or {}
+        if '_original_parameters' in parameters:
+            original_parameters = parameters.pop('_original_parameters')
+        else:
+            original_parameters = parameters
+        try:
+            self._original_parameters: Optional[dict] = copy.deepcopy(
+                original_parameters)
+        except TypeError:
+            # Copying the parameters failed because some parameters do
+            # not support being copied.
+            self._original_parameters = None
+
         if 'name' in parameters:
             self.name = parameters['name']
         elif not hasattr(self, 'name'):
@@ -125,12 +155,20 @@ class Process(metaclass=abc.ABCMeta):
         This is sufficient to reproduce the Process if there are no
         hidden states. Processes with hidden states may need to write
         their own __getstate__.
-        """
-        return self.parameters
 
-    def __setstate__(self, state: dict) -> None:
+        The original parameters saved by the constructor are used here,
+        so any later changes to the parameters will be lost during
+        serialization.
+        """
+        if self._original_parameters is None:
+            raise TypeError(
+                'Parameters could not be copied, so serialization is '
+                'not supported.')
+        return self._original_parameters
+
+    def __setstate__(self, parameters: dict) -> None:
         """Initialize process with parameters"""
-        self.__init__(parameters=state)  # type: ignore
+        self.__init__(parameters)  # type: ignore
 
     def initial_state(self, config: Optional[dict] = None) -> State:
         """Get initial state in embedded path dictionary.
@@ -220,19 +258,6 @@ class Process(metaclass=abc.ABCMeta):
             port: list(states.keys())
             for port, states in ports_schema.items()}
 
-    def local_timestep(self) -> Union[float, int]:
-        """Get a process's favored timestep.
-
-        The timestep may change over the course of the simulation.
-        Processes must not assume that their favored timestep will
-        actually be used. To customize their timestep, processes can
-        override this method.
-
-        Returns:
-            Favored timestep.
-        """
-        return self.parameters['time_step']
-
     def calculate_timestep(self, states: Optional[State]) -> Union[float, int]:
         """Return the next process time step
 
@@ -313,13 +338,45 @@ class Process(metaclass=abc.ABCMeta):
 
         This must be overridden by any subclasses.
 
+        Use the glob '*' schema to declare expected sub-store structure,
+        and view all child values of the store:
+
+          .. code-block:: python
+
+            schema = {
+                'port1': {
+                    '*': {
+                        '_default': 1.0
+                    }
+                }
+            }
+
+        Use the glob '**' schema to connect to an entire sub-branch, including
+        child nodes, grandchild nodes, etc:
+
+          .. code-block:: python
+
+            schema = {
+                'port1': '**'
+            }
+
+        Ports flagged as output-only won't be viewed through the next_update's
+        states, which can save some overhead time:
+
+          .. code-block:: python
+
+            schema = {
+              'port1': {
+                 '_output': True,
+                 'A': {'_default': 1.0},
+              }
+            }
+
         Returns:
             A dictionary that declares which states are expected by the
             processes, and how each state will behave. State keys can be
             assigned properties through schema_keys declared in
-            :py:class:`vivarium.core.store.Store`. Ports flagged with
-            {'_output': True} make it an output-only port, that won't
-            be viewed through the next_update's states.
+            :py:class:`vivarium.core.store.Store`.
         """
         return {}  # pragma: no cover
 
@@ -461,3 +518,56 @@ class ParallelProcess:
             self.stats = pstats.Stats()
             self.stats.stats = self.parent.recv()  # type: ignore
         self.multiprocess.join()
+
+
+class ToySerializedProcess(Process):
+
+    defaults: Dict[str, list] = {
+        'list': [],
+    }
+
+    def __init__(self, parameters: Optional[dict] = None) -> None:
+        super().__init__(parameters)
+        self.parameters['list'].append(1)
+
+    def ports_schema(self) -> Schema:
+        return {}
+
+    def next_update(self, timestep: float, states: State) -> Update:
+        return {}
+
+
+class ToySerializedProcessInheritance(Process):
+
+    defaults = {
+        '1': 1,
+    }
+
+    def __init__(self, parameters: Optional[dict] = None) -> None:
+        parameters = parameters or {}
+        super().__init__({
+            '2': parameters['1'],
+            '_original_parameters': parameters,
+        })
+
+    def ports_schema(self) -> Schema:
+        return {}
+
+    def next_update(self, timestep: float, states: State) -> Update:
+        return {}
+
+
+def test_serialize_process() -> None:
+    proc = ToySerializedProcess()
+    proc_pickle = pickle.loads(pickle.dumps(proc))
+
+    assert proc.parameters['list'] == [1]
+    # If we pickled using `self.parameters` instead of
+    # `self._original_parameters`, this list would be [1, 1].
+    assert proc_pickle.parameters['list'] == [1]
+
+
+def test_serialize_process_inheritance() -> None:
+    a = ToySerializedProcessInheritance({'1': 0})
+    a2 = pickle.loads(pickle.dumps(a))
+    assert a2.parameters['2'] == 0
